Enum probables::tree::Branch [−][src]
pub enum Branch {
Left,
Right,
Parent,
}Expand description
Either a branch is left one or right one Imagine binary tree
pub enum Branch {
Left,
Right,
Parent,
}Either a branch is left one or right one Imagine binary tree