Struct probables::tree::PrimaryNode [−][src]
pub struct PrimaryNode {
pub data: Vec<String>,
pub left: Vec<PrimaryNode>,
pub right: Vec<PrimaryNode>,
}Expand description
tree props implemented
Fields
data: Vec<String>data attribute: this branch hold some leaves. Each leave have own information
left: Vec<PrimaryNode>left attribute: this branch have connection with other branch of tree but which are only on left side
right: Vec<PrimaryNode>right attribute: this branch have connection with other branch of tree but which are only on right side
Implementations
“PrimaryNode” is an structure data. impl provide special functions that are helpful for this data such as root, left or right